==> cego-2.5.13.tar.gz: cego/src/CegoMediatorThread.h <==
#ifndef _CEGOMEDIATORTHREAD_H_INCLUDED_
#define _CEGOMEDIATORTHREAD_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoMediatorThread.h  
// --------------------
// thread class definition
//                                                        
// Design and Implementation by Bjoern Lemke
//
// (C)opyright 2000-2006 Bjoern Lemke
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: CegoMediatorThread
// 
// Description:
//
// Status: IMPLEMENTED
//
///////////////////////////////////////////////////////////////////////////////

#include "Chain.h"
#include "Logger.h"
#include "Thread.h"
#include "CegoDatabaseManager.h"

class CegoMediatorThread : public Thread {
    
 public:

    CegoMediatorThread(CegoDatabaseManager *pDBMng);
    ~CegoMediatorThread();

    void getDbSpec(const Chain& dbSpecFileName, const Chain& medHost, int medPort, const Chain& user, const Chain& passwd);
    void* job(void* arg);

 private:

    CegoDatabaseManager *_pDBMng;
    bool _terminated;
    bool _joined;

    unsigned long _modId;
};

#endif

==> cego-2.6.8.tar.gz: cego/src/CegoMediatorThread.h <==
#ifndef _CEGOMEDIATORTHREAD_H_INCLUDED_
#define _CEGOMEDIATORTHREAD_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoMediatorThread.h  
// --------------------
// Cego mediator thread class definition
//                                                        
// Design and Implementation by Bjoern Lemke
//
// (C)opyright 2000-2010 Bjoern Lemke
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: CegoMediatorThread
// 
// Description:
//
// Status: QG-2.6
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include "Chain.h"
#include "Logger.h"
#include "Thread.h"

// cego includes
#include "CegoDatabaseManager.h"

class CegoMediatorThread : public Thread {
    
 public:

    CegoMediatorThread(CegoDatabaseManager *pDBMng);
    ~CegoMediatorThread();

    void getDbSpec(const Chain& dbSpecFileName, const Chain& medHost, int medPort, const Chain& user, const Chain& passwd);
    void* job(void* arg);

 private:

    CegoDatabaseManager *_pDBMng;
    bool _terminated;
    bool _joined;

    unsigned long _modId;
};

#endif
